brewer <- list(
  c("#fc8d59"),
  c("#fc8d59", "#91bfdb"),
  c("#fc8d59", "#e2e2a2", "#91bfdb"),
  c("#d7191c", "#fdae61", "#abd9e9", "#2c7bb6"),
  c("#d7191c", "#fdae61", "#e2e2a2", "#abd9e9", "#2c7bb6"),
  c("#d73027", "#fc8d59", "#fee090", "#e0f3f8", "#91bfdb", "#4575b4"),
  c("#d73027", "#fc8d59", "#fee090", "#e2e2a2", "#e0f3f8", "#91bfdb", "#4575b4"),
  c("#d73027", "#f46d43", "#fdae61", "#fee090", "#e0f3f8", "#abd9e9", "#74add1", "#4575b4"),
  c("#d73027", "#f46d43", "#fdae61", "#fee090", "#e2e2a2", "#e0f3f8", "#abd9e9", "#74add1", "#4575b4"),
  c("#a50026", "#d73027", "#f46d43", "#fdae61", "#fee090", "#e0f3f8", "#abd9e9", "#74add1", "#4575b4", "#313695"),
  c("#a50026", "#d73027", "#f46d43", "#fdae61", "#fee090", "#e2e2a2", "#e0f3f8", "#abd9e9", "#74add1", "#4575b4", "#313695"),
  c("#006e82", "#8214a0", "#005ac8", "#00a0fa", "#fa78fa", "#14d2dc", "#aa0a3c", "#fa7850", "#0ab45a", "#f0f032", "#a0fa82", "#fae6be")
)
